//
//  DetailViewController.swift
//  PhotoAlbum
//
//  Created by Merlyn on 12/16/14.
//  Copyright (c) 2014 The App Lady. All rights reserved.
//

import UIKit
let reuseIdentifier = "Cell"

class DetailViewController: UIViewController, UICollectionViewDelegateFlowLayout  {

    @IBOutlet weak var editButton: UIBarButtonItem!
    @IBOutlet weak var collectionView: UICollectionView!
    
    var editModeEnabled = false
    var icon: PhotoCell!
    var selectedAlbumName = String()
    var selectedPhotoUrl = String()
    var imageCache = JKTImageCacheLibrary()
    
    // collection view dataSource object
    var cvDataSource = [String]()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        // Set the collection view's backgroundcolor to display an image
        self.collectionView!.backgroundColor = UIColor(patternImage: UIImage(named: "diamonds")!)
        
        // Register the  class with the collection view
        self.collectionView!.registerClass(PhotoCell.self, forCellWithReuseIdentifier: reuseIdentifier)
        
        self.navigationController!.title = selectedAlbumName
        
        /*for row in cvDataSource {
            println(row)
        }*/
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    // MARK: - Navigation
    
    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
        if segue.identifier == "photoDetail" {
            let controller = (segue.destinationViewController as UINavigationController).topViewController as PhotoViewController
            //controller.navigationItem.leftBarButtonItem = self.splitViewController?.displayModeButtonItem()
            //controller.navigationItem.leftItemsSupplementBackButton = true
                
            // Pass the selected photo Url for the selectedAlbumName to the PhtoViewController
            controller.selectedPhotoUrl = selectedPhotoUrl
        }
    }

    // MARK: UICollectionViewDataSource
    
    func numberOfSectionsInCollectionView(collectionView: UICollectionView) -> Int {
        // Return the number of sections
        return 1
    }
    
    func collectionView(collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
        // Return the number of urls there are in the collection view's dataSource object
        return cvDataSource.count
    }
    
    func collectionView(collectionView: UICollectionView, cellForItemAtIndexPath indexPath: NSIndexPath) -> UICollectionViewCell {
        // Initialize the reusable Collection View Cell with our custom class
        icon = collectionView.dequeueReusableCellWithReuseIdentifier(reuseIdentifier, forIndexPath: indexPath) as PhotoCell
        
        // Configure the collection view cell
        var imageUrl = cvDataSource[indexPath.row]
        
        imageCache.setImage(icon.imageView, imgUrl: imageUrl)
        
        // Convert the string variable (currentLink) to an Array variable (stringArray)
        var stringArray: Array = imageUrl.componentsSeparatedByString("/")
    
        // Remove the last element (i.e Edris-Elba.jpg) from the stringArray and put it in a string variable (link)
        var element = stringArray.removeLast()
        
        // Convert the string variable (link) to an Array variable (stringObjectArray)
        var stringObjectArray = element.componentsSeparatedByString(".")
        icon.caption.text = stringObjectArray[0]

        if editModeEnabled == false {
            icon.deleteButton.hidden = true
        } else {
            icon.deleteButton.hidden = false
            icon.shakeIcons()
        }
        
        // Give the delete button an index number
        icon.deleteButton.layer.setValue(indexPath.row, forKey: "index")
        
        // Add an action function to the delete button
        icon.deleteButton.addTarget(self, action: "deletePhotoCell:", forControlEvents: UIControlEvents.TouchUpInside)
        
        // Return the cell
        return icon
    }
    
    // MARK: UICollectionViewDelegate
    
    func collectionView(collectionView: UICollectionView, didSelectItemAtIndexPath indexPath: NSIndexPath) {
        var photoUrls = [String]()
        
        // Put the selected collection view cell's photo url in a variable
        selectedPhotoUrl = cvDataSource[indexPath.row] as String
        
        // Pass control to the PhotoViewController
        self.performSegueWithIdentifier("photoDetail", sender:self)
    }
    
    // MARK: The navigation bar's Edit button functions
    
    func deletePhotoCell(sender:UIButton) {
        // Put the index number of the delete button the user tapped in a variable
        let i: Int = (sender.layer.valueForKey("index")) as Int
        
        // Remove an object from the collection view's dataSource for the cell delete button tapped
        cvDataSource.removeAtIndex(i)
                
        // Refresh the collection view right away
        self.collectionView!.reloadData()
    }
    
    @IBAction func editButtonTapped(sender: AnyObject) {
        
        if(editModeEnabled == false) {
            // Put the collection view in edit mode
            self.editButton.title = "Done"
            self.editButton.style = .Done
            editModeEnabled = true
            
            // Loop through the collectionView's visible cells
            for item in self.collectionView!.visibleCells() as [PhotoCell] {
                var indexPath: NSIndexPath = self.collectionView!.indexPathForCell(item as PhotoCell)!
                var cell: PhotoCell = self.collectionView!.cellForItemAtIndexPath(indexPath) as PhotoCell!
                cell.deleteButton.hidden = false // show all of the delete buttons
                cell.shakeIcons()
            }
        } else {
            // Take the collection view out of edit mode
            self.editButton.style = .Plain
            self.editButton.title = "Edit"
            editModeEnabled = false
            
            // Loop through the collectionView's visible cells
            for item in self.collectionView!.visibleCells() as [PhotoCell] {
                var indexPath: NSIndexPath = self.collectionView!.indexPathForCell(item as PhotoCell)!
                var cell: PhotoCell = self.collectionView!.cellForItemAtIndexPath(indexPath) as PhotoCell!
                cell.deleteButton.hidden = true  // Hide all of the delete buttons
                cell.stopShakingIcons()
            }
        }
    }
    
    // This function is fired when the collection view begin scrolling
    func collectionView(collectionView: UICollectionView, didBeginDisplayingCell cell: UICollectionViewCell, forItemAtIndexPath indexPath: NSIndexPath) {
        
        if editModeEnabled == true {
            for cell in self.collectionView!.visibleCells() as [PhotoCell] {
                // Shake all of the collection view cells
                cell.shakeIcons()
            }
        }
    }
    
    // This function is fired when the collection view stop scrolling
    func collectionView(collectionView: UICollectionView, didEndDisplayingCell cell: UICollectionViewCell, forItemAtIndexPath indexPath: NSIndexPath) {
        
        if editModeEnabled == true {
            for cell in self.collectionView!.visibleCells() as [PhotoCell] {
                // Shake all of the collection view cells
                icon.shakeIcons()
            }
        }
    }

    func collectionView(collectionView: UICollectionView, viewForSupplementaryElementOfKind kind: String, atIndexPath indexPath: NSIndexPath) -> UICollectionReusableView {
        
        // Create an instance of the CellHeaderFooter
        var reuseableView: CellHeaderFooter!
        
        // Setup the section header label controls' properties
        if(kind == UICollectionElementKindSectionHeader!) {
            reuseableView = collectionView.dequeueReusableSupplementaryViewOfKind(kind, withReuseIdentifier: "HeaderView", forIndexPath: indexPath) as CellHeaderFooter
            
            if cvDataSource.count > 0 {
                var photoUrls = cvDataSource[indexPath.row]
                reuseableView.headerLabel1.text = " \(selectedAlbumName) Album: \(cvDataSource.count) "
            } else if cvDataSource.count == 0 {
                reuseableView.headerLabel1.text = " \(selectedAlbumName) Album: \(cvDataSource.count) "
            }

        }
        
        // Return the header/footer reusableView object
        return reuseableView
    }

}
