//
//  PhotoCellCollectionViewCell.swift
//  SwiftCollectionView
//
//  Created by Merlyn on 11/25/14.
//  Copyright (c) 2014 The App Lady. All rights reserved.
//

import UIKit

class PhotoCell: UICollectionViewCell {
    // The collection view cell's objects
    var imageView: UIImageView!
    var caption: UILabel!
    var deleteButton: UIButton!
    let deleteButtonImg: UIImage!
    var shakeEnabled = false
    
    required init(coder aDecoder: NSCoder) {
        super.init(coder: aDecoder)
    }
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        
        // Highlight the collection view's background in neon green when a cell is tapped
        selectedBackgroundView = UIView(frame: bounds)
        selectedBackgroundView.backgroundColor = UIColor(red:0.00, green:0.90, blue:0.00, alpha:1.00)
        
        // Create an ImageView and add it to the collection view
        imageView = UIImageView(frame: CGRect(x:30, y:12, width:55, height:55))
        imageView.contentMode = UIViewContentMode.ScaleAspectFill
        contentView.addSubview(imageView)
        
        // Create a Label view and add it to the collection view
        let textFrame = CGRect(x:5, y:75, width:110, height:38)
        caption = UILabel(frame: textFrame)
        caption.font = UIFont.systemFontOfSize(15.0)
        caption.textAlignment = .Center
        caption.numberOfLines = 2
        caption.lineBreakMode = NSLineBreakMode.ByWordWrapping
        caption.textColor = UIColor.blackColor()
        //caption.backgroundColor = UIColor.blackColor()
        contentView.addSubview(caption)
        
        // Create a UIButton
        deleteButton = UIButton(frame: CGRect(x: frame.size.width/10, y: frame.size.width/16, width: frame.size.width/4, height: frame.size.width/4))
        
        // Set the UIButton's image property
        deleteButtonImg = UIImage(named: "delete-icon")!
        deleteButton.setImage(deleteButtonImg, forState: UIControlState.Normal)
        
        // Add the UIButton to the collection view
        contentView.addSubview(deleteButton)
    }
    
    // This function shake the collection view cells
    func shakeIcons() {
        let shakeAnim = CABasicAnimation(keyPath: "transform.rotation")
        shakeAnim.duration = 0.05
        shakeAnim.repeatCount = 2
        shakeAnim.autoreverses = true
        let startAngle: Float = (-2) * 3.14159/180
        var stopAngle = -startAngle
        shakeAnim.fromValue = NSNumber(float: startAngle)
        shakeAnim.toValue = NSNumber(float: 3 * stopAngle)
        shakeAnim.autoreverses = true
        shakeAnim.duration = 0.2
        shakeAnim.repeatCount = 10000
        shakeAnim.timeOffset = 290 * drand48()
        
        //Create layer, then add animation to the element's layer
        let layer: CALayer = self.layer
        layer.addAnimation(shakeAnim, forKey:"shaking")
        shakeEnabled = true
    }

    
    // This function stop shaking the collection view cells
    func stopShakingIcons() {
        let layer: CALayer = self.layer
        layer.removeAnimationForKey("shaking")
        self.deleteButton.hidden = true
        shakeEnabled = false
    }
}
